#include <unistd.h>
#include <ctype.h>
#include <string.h>
#include <stdio.h>
#include <sysexits.h>
#include <signal.h>
#include <stdarg.h>
#include <npapi.h>
#include <sys/stat.h>
#include <sys/wait.h>
#include <errno.h>
#include <sys/time.h>
#include <X11/X.h>
#include <X11/Xos.h>
#include <X11/Intrinsic.h>
#include <X11/Xatom.h>
#include <sys/socket.h>

/*****************************************************************************
 * Defines
 *****************************************************************************/

#ifndef MAXINT
#define MAXINT 0x7fffffff
#endif

#define MAX(X,Y) ((X)>(Y)?(X):(Y))

/* Timeout for select() */
#define SELECT_TIMEOUT_SEC  0
#define SELECT_TIMEOUT_USEC 100*1000

/* Time to wait for a process to exit */
#define KILL_TIMEOUT_USEC 100000

/* Flags */
#define H_LOOP 		0x1
#define H_DAEMON 	0x2
#define H_STREAM 	0x4
#define H_NOISY 	0x8
#define H_REPEATCOUNT 	0x10
#define H_EMBED         0x20
#define H_NOEMBED       0x40
#define H_IGNORE_ERRORS 0x80
#define H_SWALLOW 	0x100
#define H_MAXASPECT 	0x200
#define H_FILL 		0x400
#define H_HIDDEN        0x800
#define H_CONTROLS 	0x1000

/*****************************************************************************
 * mozplugger-common.c functions
 *****************************************************************************/
#ifdef DEBUG
void close_debug();
#endif
void D(char *fmt, ...);
void my_kill(int pid);
